
import gconf

import gtk
try :
    import hildon
except :
    hildon = False

class Configuration :

    def __init__ ( self ) :
        self.homedir = None
        self.dbname = None
        self.mapsdir , self.mapclass = None , None
        self.lat , self.lon = 0.0 , 0.0
        self.zoom = 0
        self.read()

    def read ( self ) :
        client = gconf.client_get_default()
        self.homedir = client.get_string( "/apps/wifihood/basedir" ) or "/home/user/MyDocs"
        self.dbname = client.get_string( "/apps/wifihood/dbname" ) or "wifiscanner.db"
        self.mapsdir = client.get_string( "/apps/wifihood/maps" ) or "/home/user/MyDocs/.maps"
        self.mapclass = client.get_string( "/apps/wifihood/maptype" ) or "OpenStreetMap I"
        self.lat = client.get_float( "/apps/wifihood/lattitude" ) or client.get_float( "/apps/maemo/maemo-mapper/center_latitude" ) or 40.416
        self.lon = client.get_float( "/apps/wifihood/longitude" ) or client.get_float( "/apps/maemo/maemo-mapper/center_longitude" ) or -3.683
        self.zoom = client.get_int( "/apps/wifihood/zoom" ) or client.get_float( "/apps/maemo/maemo-mapper/zoom" ) or 15

    def save ( self ) :
        client = gconf.client_get_default()
        client.set_string( "/apps/wifihood/basedir" , self.homedir )
        client.set_string( "/apps/wifihood/dbname" , self.dbname )
        client.set_string( "/apps/wifihood/maps" , self.mapsdir )
        client.set_string( "/apps/wifihood/maptype" , self.mapclass )
        client.set_float( "/apps/wifihood/lattitude" , self.lat )
        client.set_float( "/apps/wifihood/longitude" , self.lon )
        client.set_int( "/apps/wifihood/zoom" , self.zoom )


class AbstractSettingsWindow :

    def __init__ ( self , config ) :
        self.set_title( "Wifihood Settings" )

        scrollwin = self.MainArea()
        scrollwin.show()
        self.add(scrollwin)

        vbox = gtk.VBox(False, 0)
        vbox.show()
        scrollwin.add_with_viewport( vbox )


        dbframe = gtk.Frame( label="Database" )
        dbframe.set_label_align(0 , 0.1)
        dbframe.show()
        vbox.pack_start(dbframe, True, True, 0)

        database = gtk.Table(2, 2, False)
        database.show()
        dbframe.add(database)

        dblabel = gtk.Label( "Home directory" )
        dblabel.show()
        database.attach(dblabel, 0, 1, 0, 1, gtk.EXPAND|gtk.FILL, 0, 0, 5)

        dbvalue = self.Entry()
        dbvalue.set_text( config.homedir )
        dbvalue.show()
        database.attach(dbvalue, 1, 2, 0, 1, gtk.EXPAND|gtk.FILL, 0, 0, 5)

        dblabel = gtk.Label( "Database name" )
        dblabel.show()
        database.attach(dblabel, 0, 1, 1, 2, gtk.EXPAND|gtk.FILL, 0, 0, 5)

        dbvalue = self.Entry()
        dbvalue.set_text( config.dbname )
        dbvalue.show()
        database.attach(dbvalue, 1, 2, 1, 2, gtk.EXPAND|gtk.FILL, 0, 0, 5)


        mapsframe = gtk.Frame( label="Maps" )
        mapsframe.set_label_align(0 , 0.1)
        mapsframe.show()
        vbox.pack_start(mapsframe, True, True, 0)

        maps = gtk.Table(2, 2, False)
        maps.show()
        mapsframe.add(maps)

        button = self.CheckButton()
        button.set_label( "Use OpenStreet maps" )
        button.set_active( 1 )
        button.show()
        maps.attach(button, 0, 1, 0, 1, gtk.EXPAND|gtk.FILL, 0, 0, 5)

        zoomlevel = self.Button( "Zoom level" , config.zoom )
        zoomlevel.connect_object( "clicked", self.zoomdialog, config )
        zoomlevel.show()
        maps.attach(zoomlevel, 1, 2, 0, 1, gtk.EXPAND|gtk.FILL, 0, 0, 5)


        gpsframe = gtk.Frame( label="Coordinates" )
        gpsframe.set_label_align(0 , 0.1)
        gpsframe.show()
        vbox.pack_start(gpsframe, True, True, 0)

        gps = gtk.Table(2, 2, False)
        gps.show()
        gpsframe.add(gps)

        button = self.CheckButton()
        button.set_label( "Take initial coordinates from maemo-mapper" )
        button.show()
        gps.attach(button, 0, 2, 0, 1, gtk.EXPAND|gtk.FILL) #, 0, 0, 5)

        button = self.CheckButton()
        button.set_label( "Store changes in coordinates" )
        button.show()
        gps.attach(button, 0, 2, 1, 2, gtk.EXPAND|gtk.FILL) #, 0, 0, 5)


        dataframe = gtk.Frame( label="Data gathering" )
        dataframe.set_label_align(0 , 0.1)
        dataframe.show()
        vbox.pack_start(dataframe, True, True, 0)

        button = self.CheckButton()
        button.set_label( "Write full logfile" )
        button.show()
        dataframe.add(button)

        self.show()

    def zoomdialog ( self , widget) :
        dialog = ZoomDialog( widget )
        dialog.show_all()

if hildon :

  class ZoomDialog ( hildon.TouchSelector ) :

    def __init__ ( self , config ) :
        hildon.TouchSelector.__init__( self )

        zooms = gtk.ListStore(str)

        active = index = 0
        for zoom in range(8,19) :
            iter = zooms.append()
            zooms.set( iter , 0 , "%2d" % zoom )
            if zoom == config.zoom :
                active = index
            index += 1

        column = self.append_text_column( zooms , True )

        # NOTE : with text=True, we must use 1 instead of 0
        self.set_active( 0 , active )

  class SettingsWindow ( hildon.StackableWindow , AbstractSettingsWindow ) :

    def __init__ ( self , config ) :
        hildon.StackableWindow.__init__( self )
        AbstractSettingsWindow.__init__( self , config )

    def MainArea ( self ) :
        return hildon.PannableArea()

    def Entry ( self ) :
        return hildon.Entry( gtk.HILDON_SIZE_FINGER_HEIGHT )

    def Button ( self , text , value ) :
        return hildon.Button( gtk.HILDON_SIZE_THUMB_HEIGHT , hildon.BUTTON_ARRANGEMENT_HORIZONTAL , text , "%s" % value )

    def CheckButton ( self ) :
        return hildon.CheckButton( gtk.HILDON_SIZE_FINGER_HEIGHT )

else :

  class ZoomDialog ( gtk.Dialog ) :

    def __init__ ( self , config ) :
        gtk.Dialog.__init__( self , "Select zoom level",
                             None,
                             gtk.DIALOG_MODAL,
                             ( gtk.STOCK_OK, gtk.RESPONSE_ACCEPT,
                               gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT
                               )
                             )

        zooms = gtk.ListStore(int)
        combo = gtk.ComboBox( zooms )

        for zoom in range(8,19) :
            iter = zooms.append()
            zooms.set( iter , 0 , zoom )
            if zoom == config.zoom :
                combo.set_active_iter( iter )

        cell = gtk.CellRendererText()
        combo.pack_start(cell, True)
        combo.add_attribute(cell, 'text', 0)

        self.vbox.pack_start(combo , True, True, 0)

        self.connect_object( "response", self.response , combo , config )

    def response ( self , combo , response  , config ) :
        if response == gtk.RESPONSE_ACCEPT :
            item = combo.get_active_iter()
            model = combo.get_model()
            config.zoom = model.get(item,0)[0]
        self.destroy()

  class SettingsWindow ( gtk.Window , AbstractSettingsWindow ) :

    def __init__ ( self , config ) :
        gtk.Window.__init__( self )
        AbstractSettingsWindow.__init__( self , config )

    def MainArea ( self ) :
        scrollwin = gtk.ScrolledWindow()
        scrollwin.set_size_request(-1, 260)
        scrollwin.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
        return scrollwin

    def Entry ( self ) :
        return gtk.Entry()

    def Button ( self , text , value ) :
        return gtk.Button( "%s %s" % ( text , value ) )

    def CheckButton ( self ) :
        return gtk.CheckButton()

config = Configuration()

if __name__ == "__main__" :
    window = SettingsWindow( config )
    window.connect("delete_event", gtk.main_quit, None)
    window.show()
    gtk.main()
